@@ -4,7 +4,7 @@ from json import dump
 from logging import basicConfig
 from multiprocessing import Pool
 
-from homeinfotools.functions import get_log_level
+from homeinfotools.functions import get_log_level, handle_keyboard_interrupt
 from homeinfotools.logging import LOG_FORMAT
 from homeinfotools.rpc.argparse import get_args
 from homeinfotools.rpc.worker import Worker
@@ -13,6 +13,7 @@ from homeinfotools.rpc.worker import Worker
 __all__ = ['main']
 
 
+@handle_keyboard_interrupt
 def main() -> None:
     """Runs the script."""
 
